<template>
  <div
    class="exception-div"
    style="padding:0px 14px;height: 100%;overflow: auto;"
  >
    <div class="mod-config">
      <div class="need-feed-header">
        <div style="height:28px;line-height:28px; margin-left: 20px">
          <el-divider class="pane-divider" direction="vertical"></el-divider
          ><span style="font-size:14px;font-weight:bold">生产异常反馈列表</span>
        </div>
      </div>
      <el-row>
        <el-col :span="15">
          <ttable
            :table="table"
            @handleSelectionChange="handleSelectionChange"
            @currentChange="handleCurrentChange"
            :uploadInfo="uploadInfo"
            :prelang="prelang"
            :options="options"
            :ajaxFun="ajaxFun"
            ref="exceptionTable"
          >
            <template #toolbar></template>
          </ttable>
        </el-col>
        <el-col :span="9" style="margin-top: 80px">
          <el-upload
            class="upload-demo"
            action="/mes/exception/upload"
            :headers="headers"
            :before-upload="submitUpload"
            :on-preview="handlePreview"
            :on-remove="handleRemove"
            :on-success="uploadSuccess"
            :data="paramData"
            :file-list="fileList"
            list-type="picture"
            :with-credentials="true"
          >
            <el-button size="small" type="primary">点击上传</el-button>
            <div slot="tip" class="el-upload__tip">
              只能上传jpg图片，且不超过2MB
            </div>
          </el-upload>
        </el-col>
      </el-row>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </div>
  </div>
</template>
<style lang="scss" scoped>
.pane-divider {
  width: 4px;
  background-color: #4283ee;
}
.exception-div >>> .inspection-btn {
  background-image: -webkit-linear-gradient(139deg, #5f6eef 0%, #2783ff 100%);
  background-image: -moz-linear-gradient(139deg, #5f6eef 0%, #2783ff 100%);
  background-image: linear-gradient(139deg, #5f6eef 0%, #2783ff 100%);
  color: #fff;
  border-color: #fbecec;
  border-radius: 15px;
  padding: 6px 15px;
}
.exception-div >>> .inspection-btn span {
  margin-left: 3px;
}
.exception-div >>> .commonTable .el-table__header th {
  background: #599ef4 !important;
  color: #fff !important;
  border: 0px !important;
}
.exception-div >>> .feed-btn-return {
  background: url('/img/workbench/icon_xz1.png') center center no-repeat;
  background-size: cover;
  font-size: 14px;
}

.exception-div >>> .feed-btn-return:before {
  content: '新';
  font-size: 14px;
  visibility: hidden;
}
.exception-div >>> .common-table-div {
  margin: 0px 20px 0px !important;
}
</style>
<script>
import { fetchList, delObj } from '@/api/quality/exception'
import TableForm from './exceptionform'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { getStore } from '../../../util/store'
import {
  getExceptionAttachment,
  removeFile
} from '../../../api/quality/exception'
export default {
  props: {
    workstationId: {
      type: Number,
      default: null
    }
  },
  data() {
    return {
      fileList: [],
      headers: {
        Authorization: 'Bearer ' + getStore({ name: 'access_token' })
      },
      ajaxFun: fetchList,
      addOrUpdateVisible: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      paramData: {
        exceptionId: null
      },
      currentRow: null,
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 零件号
          {
            minWidth: '30',
            prop: 'code',
            label: '编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 名称
          {
            minWidth: '120',
            prop: 'workstationName',
            label: '工作站',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 物料类型
          {
            minWidth: '140',
            prop: 'productNo',
            label: '产出',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 国家
          {
            minWidth: '120',
            prop: 'exceptionType',
            label: '异常类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 描述
          {
            minWidth: '140',
            prop: 'exceptionDescription',
            label: '异常描述',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 种类
          {
            minWidth: '140',
            prop: 'handleWay',
            label: '处理方案',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 品类
          {
            minWidth: '120',
            prop: 'createUser',
            label: '处理人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 规格
          {
            minWidth: '140',
            prop: 'createTime',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            cls: 'inspection-btn',
            icon: 'feed-btn-return',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      }
    }
  },
  components: {
    TableForm,
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.exceptionTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(
          row == null ? null : row.id,
          this.workstationId,
          this.productionMainId == null ? null : this.productionMainId
        )
      })
    },
    init(productionMainId) {
      // 选中报告抛过来的报工id
      this.productionMainId = productionMainId
    },
    handleRemove(file, fileList) {
      if (this.currentRow) {
        removeFile(
          Object.assign({
            fileName: file.fileName
          })
        ).then((response) => {})
      }
    },
    handlePreview(file) {
      window.open(file.url)
    },
    uploadSuccess(response, file, fileList) {
      this.getFileList()
    },
    getFileList() {
      this.fileList = []
      if (this.currentRow && this.currentRow.id) {
        getExceptionAttachment(this.currentRow.id).then((response) => {
          var attachments = response.data.data
          // 渲染附件
          if (attachments != null && attachments.length > 0) {
            var attachment
            var fileEl
            for (var i = 0; i < attachments.length; i++) {
              attachment = attachments[i]
              fileEl = {}
              fileEl.name = attachment.original
              fileEl.url = attachment.url
              fileEl.id = attachment.id
              fileEl.fileName = attachment.fileName
              this.fileList.push(fileEl)
            }
          }
        })
      }
    },
    submitUpload() {
      console.info(this.currentRow && this.currentRow.id)
      if (this.currentRow && this.currentRow.id) {
        this.paramData.exceptionId = this.currentRow.id
      } else {
        this.$message.error('请先选择生产异常记录')
        return false
      }
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除此生产异常反馈编号为：' + row.code + '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    handleCurrentChange(val) {
      this.currentRow = val
      this.uploadSuccess()
    }
  }
}
</script>
